==> sadad_payment_flutter-0.0.35.tar.gz: lib/assets/locale/arabic.dart <==
Map<String, String> ar ={
  "Or Pay Using" : "أو الدفع باستخدام",
  "Credit Card" : "بطاقة إئتمان",
  "Debit Card" : "بطاقة ائتمان",
  "Sadad Pay" : "سداد الدفع",
  "Okay" : "تمام",
  "Pay" : "يدفع",
  "Please try with valid amount!" : "يرجى المحاولة بكمية صالحة!",
  "The Given Transaction Amount is less than " : "مبلغ المعاملة المقدم أقل من",
  "Something went wrong. Please try again" : "حدث خطأ ما. أعد المحاولة من فضلك",
  "Please enter amount upto 2 decimal points" : "الرجاء إدخال مبلغ حتى نقطتين عشريتين",
  "American Express card not allowed for your merchant." : "بطاقة أمريكان إكسبريس غير مسموح بها للتاجر الخاص بك.",
  "(You are safe)" : "(انت آمن)",
  "Payment is Secured with 256bit SSL encryption " : "الدفع مؤمن بتشفير 256 بت SSL",
  "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation." : "عندما تختار إتمام الدفع باستخدام بطاقة الخصم الصادرة في قطر ، فسيتم إعادة توجيهك مؤقتًا إلى موقع QPay الإلكتروني. بمجرد اكتمال المعاملة ، سيتم نقلك مرة أخرى إلى سداد لعرض التأكيد الخاص بك.",
  "Password" : "كلمة المرور",
  "Cell Number" : "رقم الخلوي",
  "Expiry / Validity" : "انتهاء الصلاحية / الصلاحية",
  "Card Number" : "رقم البطاقة",
  "Card Holder Name" : "إسم صاحب البطاقة",
  "Select an option to Pay " : "حدد خيارًا للدفع",
  "Merchant has no permission to use SDK. Please contact to administrator." : "التاجر ليس لديه إذن لاستخدام SDK. الرجاء الاتصال بالمسؤول.",

  "100% secured Payment ": "دفع مضمون 100٪",
  "Powered by Sadad": "بدعم من Sadad",
  "Login with your Sadad account": "تسجيل الدخول باستخدام حساب Sadad الخاص بك",
  "CVV is the three digit number on the back of your credit/debit card.": "CVV هو الرقم المكون من ثلاثة أرقام على ظهر بطاقة الائتمان / الخصم الخاصة بك.",
  "What is CVV": "ما هو CVV",
  "Please enter card holder name": "الرجاء إدخال اسم حامل البطاقة",
  "Card holder name is invalid.": "اسم حامل البطاقة غير صالح.",
  "Please enter card number": "الرجاء إدخال رقم البطاقة",
  "Please enter a valid credit card number.": "الرجاء إدخال رقم بطاقة ائتمان صالحة.",
  "We are not accepting this card": "نحن لا نقبل هذه البطاقة",
  "This is not a valid credit card number": "هذا ليس رقم بطاقة ائتمان صالحًا",
  "Please enter expiry.": "الرجاء إدخال تاريخ انتهاء الصلاحية.",
  "Enter valid expiry.": "أدخل انتهاء صلاحية صالحًا.",
  "Please enter CVV": "الرجاء إدخال CVV",
  "Please enter valid expiry.": "الرجاء إدخال انتهاء صلاحية صالح.",
  "Please enter valid CVV": "الرجاء إدخال CVV صالح",
  "Not Allowed": "غير مسموح",
  "Transaction is not allowed from your country.": "المعاملة غير مسموح بها من بلدك.",
  "Please enter cell number.": "الرجاء إدخال رقم الخلية.",
  "Please enter valid cell number": "الرجاء إدخال رقم هاتف صالح",
  "Please enter password": "الرجاء إدخال كلمة المرور",
  "Issue": "مشكلة",
  "We are not able to proceed please try again.": "لم نتمكن من المتابعة ، يرجى المحاولة مرة أخرى.",
  "Something went wrong": "هناك خطأ ما",
  "OTP Verification": "التحقق من OTP",
  "OTP is valid Upto ": "كلمة المرور لمرة واحدة صالحة حتى",
  "Can't receive the OTP? ": "لا يمكن استلام OTP؟",
  "Resend": "إعادة إرسال",
  "seconds": "ثواني",
};

==> sadad_payment_flutter-0.0.37.tar.gz: lib/assets/locale/arabic.dart <==
Map<String, String> ar ={
  "Or Pay Using" : "أو الدفع باستخدام",
  "Credit Card" : "بطاقة إئتمان",
  "Debit Card" : "بطاقة ائتمان",
  "Sadad Pay" : "سداد الدفع",
  "Okay" : "تمام",
  "Pay" : "يدفع",
  "Please try with valid amount!" : "يرجى المحاولة بكمية صالحة!",
  "The Given Transaction Amount is less than " : "مبلغ المعاملة المقدم أقل من",
  "Something went wrong. Please try again" : "حدث خطأ ما. أعد المحاولة من فضلك",
  "Please enter amount upto 2 decimal points" : "الرجاء إدخال مبلغ حتى نقطتين عشريتين",
  "American Express card not allowed for your merchant." : "بطاقة أمريكان إكسبريس غير مسموح بها للتاجر الخاص بك.",
  "(You are safe)" : "(انت آمن)",
  "Payment is Secured with 256bit SSL encryption " : "الدفع مؤمن بتشفير 256 بت SSL",
  "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation." : "عندما تختار إتمام الدفع باستخدام بطاقة الخصم الصادرة في قطر ، فسيتم إعادة توجيهك مؤقتًا إلى موقع QPay الإلكتروني. بمجرد اكتمال المعاملة ، سيتم نقلك مرة أخرى إلى سداد لعرض التأكيد الخاص بك.",
  "Password" : "كلمة المرور",
  "Cell Number" : "رقم الخلوي",
  "Expiry / Validity" : "انتهاء الصلاحية / الصلاحية",
  "Card Number" : "رقم البطاقة",
  "Card Holder Name" : "إسم صاحب البطاقة",
  "Select an option to Pay " : "حدد خيارًا للدفع",
  "Merchant has no permission to use SDK. Please contact to administrator." : "التاجر ليس لديه إذن لاستخدام SDK. الرجاء الاتصال بالمسؤول.",

  "100% secured Payment ": "دفع مضمون 100٪",
  "Powered by Sadad": "بدعم من Sadad",
  "Login with your Sadad account": "تسجيل الدخول باستخدام حساب Sadad الخاص بك",
  "CVV is the three digit number on the back of your credit/debit card.": "CVV هو الرقم المكون من ثلاثة أرقام على ظهر بطاقة الائتمان / الخصم الخاصة بك.",
  "What is CVV": "ما هو CVV",
  "Please enter card holder name": "الرجاء إدخال اسم حامل البطاقة",
  "Card holder name is invalid.": "اسم حامل البطاقة غير صالح.",
  "Please enter card number": "الرجاء إدخال رقم البطاقة",
  "Please enter a valid credit card number.": "الرجاء إدخال رقم بطاقة ائتمان صالحة.",
  "We are not accepting this card": "نحن لا نقبل هذه البطاقة",
  "This is not a valid credit card number": "هذا ليس رقم بطاقة ائتمان صالحًا",
  "Please enter expiry.": "الرجاء إدخال تاريخ انتهاء الصلاحية.",
  "Enter valid expiry.": "أدخل انتهاء صلاحية صالحًا.",
  "Please enter CVV": "الرجاء إدخال CVV",
  "Please enter valid expiry.": "الرجاء إدخال انتهاء صلاحية صالح.",
  "Please enter valid CVV": "الرجاء إدخال CVV صالح",
  "Not Allowed": "غير مسموح",
  "Transaction is not allowed from your country.": "المعاملة غير مسموح بها من بلدك.",
  "Please enter cell number.": "الرجاء إدخال رقم الخلية.",
  "Please enter valid cell number": "الرجاء إدخال رقم هاتف صالح",
  "Please enter password": "الرجاء إدخال كلمة المرور",
  "Issue": "مشكلة",
  "We are not able to process your payment.": "لم نتمكن من المتابعة ، يرجى المحاولة مرة أخرى.",
  "Something went wrong": "هناك خطأ ما",
  "OTP Verification": "التحقق من OTP",
  "OTP is valid Upto ": "كلمة المرور لمرة واحدة صالحة حتى",
  "Can't receive the OTP? ": "لا يمكن استلام OTP؟",
  "Resend": "إعادة إرسال",
  "seconds": "ثواني",
};
